import numpy as np
import random
from collections import Counter

# 1. 独立事象
# 例: コインを2回投げた場合、それぞれの結果は独立
prob_coin1 = 0.5  # コイン1が表になる確率
prob_coin2 = 0.5  # コイン2が表になる確率
independent_probability = prob_coin1 * prob_coin2
print(f"コイン2枚が両方表になる確率: {independent_probability}")

# 2. 条件付き確率
# 例: 簡易的な条件付き確率計算
p_a_and_b = 0.2  # AとBが同時に発生する確率
p_b = 0.5  # Bが発生する確率
conditional_probability = p_a_and_b / p_b
print(f"条件付き確率 P(A | B): {conditional_probability}")

# 3. 大数の法則
# コイン投げシミュレーション
trials = 10000
results = [random.choice(["表", "裏"]) for _ in range(trials)]
proportion_heads = Counter(results)["表"] / trials
print(f"試行回数 {trials} 回での表の割合: {proportion_heads:.2f}")

# 4. 中心極限定理
# 乱数の平均を取り、その分布をプロット
sample_means = []
for _ in range(1000):
    sample = np.random.uniform(0, 1, 30)  # 0〜1の一様分布からサンプル
    sample_means.append(np.mean(sample))

# 結果を可視化
import matplotlib.pyplot as plt

plt.hist(sample_means, bins=30, color="blue", alpha=0.7, edgecolor="black")
plt.title("中心極限定理: サンプル平均の分布")
plt.xlabel("サンプル平均")
plt.ylabel("頻度")
plt.show()
