import numpy as np
import pandas as pd
from sklearn.linear_model import LinearRegression
import matplotlib.pyplot as plt

# サンプルデータ作成
np.random.seed(42)
X = np.random.rand(50) * 10  # 説明変数
y = 2.5 * X + np.random.randn(50) * 2  # 目的変数（傾き2.5 + ノイズ）

# データをDataFrameに格納
df = pd.DataFrame({"X": X, "y": y})

# モデルの作成と学習
model = LinearRegression()
model.fit(df[["X"]], df["y"])

# モデルのパラメータ
print(f"回帰直線の傾き: {model.coef_[0]:.2f}")
print(f"回帰直線の切片: {model.intercept_:.2f}")

# 予測値の計算
df["Predicted_y"] = model.predict(df[["X"]])

# プロット
plt.scatter(df["X"], df["y"], color="blue", label="実測値")
plt.plot(df["X"], df["Predicted_y"], color="red", label="回帰直線")
plt.title("単回帰分析")
plt.xlabel("説明変数 X")
plt.ylabel("目的変数 y")
plt.legend()
plt.show()
