import numpy as np
import pandas as pd
from sklearn.linear_model import LinearRegression
from sklearn.metrics import mean_squared_error, r2_score
import matplotlib.pyplot as plt

# サンプルデータ作成
np.random.seed(42)
X1 = np.random.rand(50) * 10  # 説明変数1
X2 = X1 + np.random.rand(50)  # 説明変数2（高い相関を持つ）
y = 3 * X1 + 1.5 * X2 + np.random.randn(50) * 2  # 目的変数

# データをDataFrameに格納
df = pd.DataFrame({"X1": X1, "X2": X2, "y": y})

# モデルの作成と学習
model = LinearRegression()
model.fit(df[["X1", "X2"]], df["y"])

# 1. 決定係数（R²）
r2 = r2_score(df["y"], model.predict(df[["X1", "X2"]]))
print(f"決定係数 (R²): {r2:.2f}")

# 2. 標準誤差
mse = mean_squared_error(df["y"], model.predict(df[["X1", "X2"]]))
standard_error = np.sqrt(mse)
print(f"標準誤差: {standard_error:.2f}")

# 3. 多重共線性（説明変数間の相関分析）
correlation_matrix = df[["X1", "X2"]].corr()
print("\n説明変数間の相関行列:")
print(correlation_matrix)

# 4. 残差分析
df["Residuals"] = df["y"] - model.predict(df[["X1", "X2"]])

# 残差プロット
plt.scatter(df["y"], df["Residuals"], color="blue", alpha=0.7)
plt.axhline(y=0, color="red", linestyle="--")
plt.title("残差分析")
plt.xlabel("実測値")
plt.ylabel("残差")
plt.show()
