import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
from scipy.stats import skew, kurtosis

# 1. サンプルデータ作成（架空の映画レビュー評価データ）
np.random.seed(42)
movie_ratings = np.random.randint(1, 11, 100)  # 1〜10の範囲で100人の評価

# データをDataFrameに格納
df = pd.DataFrame({"MovieRatings": movie_ratings})

# 2. 記述統計を計算
mean_rating = df["MovieRatings"].mean()
median_rating = df["MovieRatings"].median()
mode_rating = df["MovieRatings"].mode().iloc[0]
variance_rating = df["MovieRatings"].var()
std_dev_rating = df["MovieRatings"].std()
range_rating = df["MovieRatings"].max() - df["MovieRatings"].min()
q1 = df["MovieRatings"].quantile(0.25)
q3 = df["MovieRatings"].quantile(0.75)
iqr = q3 - q1
skewness = skew(df["MovieRatings"])
kurt = kurtosis(df["MovieRatings"])

# 結果の出力
print("=== 記述統計 ===")
print(f"平均: {mean_rating:.2f}")
print(f"中央値: {median_rating}")
print(f"モード: {mode_rating}")
print(f"分散: {variance_rating:.2f}")
print(f"標準偏差: {std_dev_rating:.2f}")
print(f"範囲: {range_rating}")
print(f"四分位範囲 (IQR): {iqr:.2f}")
print(f"歪度: {skewness:.2f}")
print(f"尖度: {kurt:.2f}")

# 3. データの可視化
# ヒストグラム
plt.hist(df["MovieRatings"], bins=10, color="blue", edgecolor="black", alpha=0.7)
plt.title("映画レビューの評価分布")
plt.xlabel("評価スコア")
plt.ylabel("頻度")
plt.show()

# 箱ひげ図
plt.boxplot(df["MovieRatings"], vert=False, patch_artist=True)
plt.title("映画レビューの箱ひげ図")
plt.xlabel("評価スコア")
plt.show()

# 4. データ分析からの発見
print("\n=== 分析からの発見 ===")
if mean_rating >= 7:
    print("この映画は高評価が多いと考えられます！")
elif mean_rating < 4:
    print("この映画は低評価が多い傾向にあります。")
else:
    print("この映画の評価は平均的です。")

if skewness > 0:
    print("評価スコアに右側の裾が長い分布があります。")
elif skewness < 0:
    print("評価スコアに左側の裾が長い分布があります。")
else:
    print("評価スコアは対称的な分布です。")

if kurt > 0:
    print("分布に鋭いピークが見られます（尖度が高い）。")
elif kurt < 0:
    print("分布に平坦な形状が見られます（尖度が低い）。")
else:
    print("分布は正規分布に近い形状です。")
